@@ -1,5 +1,5 @@
 download_parquet = function(data_id, server, desc = download_desc_data(data_id, server), file = NULL) {
-  get_parquet(desc$minio_url, api_key = get_api_key(server), file = file)
+  get_parquet(desc$parquet_url, api_key = get_api_key(server), file = file)
 }
 
 get_parquet = function(url, ..., server, api_key = get_api_key(server), retries = getOption("mlr3oml.retries", 3L), file = NULL) {
